@@ -3,10 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_mpu6050
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 mpu = adafruit_mpu6050.MPU6050(i2c)
 
 while True:
